# Generated by roxygen2: do not edit by hand

S3method(AIC,modal_arima)
S3method(BIC,modal_arima)
S3method(coef,modal_arima)
S3method(diagnostics,modal_arima)
S3method(envelope,modal_arima)
S3method(fitted,modal_arima)
S3method(forecast,modal_arima)
S3method(logLik,modal_arima)
S3method(plot,modal_arima)
S3method(predict,modal_arima)
S3method(print,modal_arima)
S3method(residuals,modal_arima)
S3method(summary,modal_arima)
export(auto.modal.arima)
export(diagnostics)
export(envelope)
export(fit_modal_arima)
export(forecast)
import(ggplot2)
importFrom(forecast,forecast)
importFrom(forecast,ndiffs)
importFrom(graphics,plot)
importFrom(grid,gpar)
importFrom(grid,textGrob)
importFrom(gridExtra,grid.arrange)
importFrom(scales,comma_format)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,Box.test)
importFrom(stats,acf)
importFrom(stats,arima)
importFrom(stats,coef)
importFrom(stats,dnorm)
importFrom(stats,frequency)
importFrom(stats,integrate)
importFrom(stats,is.ts)
importFrom(stats,logLik)
importFrom(stats,optim)
importFrom(stats,pacf)
importFrom(stats,pnorm)
importFrom(stats,predict)
importFrom(stats,printCoefmat)
importFrom(stats,qnorm)
importFrom(stats,qqline)
importFrom(stats,qqnorm)
importFrom(stats,residuals)
importFrom(stats,rgamma)
importFrom(stats,runif)
importFrom(stats,shapiro.test)
importFrom(stats,start)
importFrom(stats,time)
importFrom(stats,ts)
importFrom(stats,uniroot)
