% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics.R
\name{envelope}
\alias{envelope}
\alias{envelope.modal_arima}
\title{Simulation Envelope Diagnostics for Modal ARIMA Models}
\usage{
envelope(object, ...)

\method{envelope}{modal_arima}(object, B = 100, ...)
}
\arguments{
\item{object}{An object of class \code{modal_arima}.}

\item{...}{Additional arguments (unused).}

\item{B}{Number of Monte Carlo replications for envelope construction. Default is 100.}
}
\value{
A ggplot object (invisibly) and draws the envelope plot.
}
\description{
Constructs simulation envelopes based on the theoretical distance
distributions from the SKD family (Galarza et al., 2017).
}
